package com.ruoyi.sim.mapper;

import java.util.List;

import com.ruoyi.sim.domain.RealExam;

/**
 * 考试Mapper接口
 *
 * @author tom
 * @date 2024-12-15
 */
public interface RealExamMapper {
    /**
     * 查询考试
     *
     * @param examId 考试主键
     * @return 考试
     */
    public RealExam selectRealExamByExamId(Long examId);

    /**
     * 查询考试列表
     *
     * @param realExam 考试
     * @return 考试集合
     */
    public List<RealExam> selectRealExamList(RealExam realExam);

    /**
     * 新增考试
     *
     * @param realExam 考试
     * @return 结果
     */
    public int insertRealExam(RealExam realExam);

    /**
     * 修改考试
     *
     * @param realExam 考试
     * @return 结果
     */
    public int updateRealExam(RealExam realExam);

    /**
     * 删除考试
     *
     * @param examId 考试主键
     * @return 结果
     */
    public int deleteRealExamByExamId(Long examId);

    /**
     * 批量删除考试
     *
     * @param examIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRealExamByExamIds(Long[] examIds);
}
